==> apache-camel-4.10.8-src.zip: apache-camel-4.10.8/core/camel-core-reifier/src/main/java/org/apache/camel/reifier/SetExchangePatternReifier.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.reifier;

import org.apache.camel.ExchangePattern;
import org.apache.camel.Processor;
import org.apache.camel.Route;
import org.apache.camel.model.ProcessorDefinition;
import org.apache.camel.model.SetExchangePatternDefinition;
import org.apache.camel.processor.ExchangePatternProcessor;

public class SetExchangePatternReifier extends ProcessorReifier<SetExchangePatternDefinition> {

    public SetExchangePatternReifier(Route route, ProcessorDefinition<?> definition) {
        super(route, (SetExchangePatternDefinition) definition);
    }

    @Override
    public Processor createProcessor() {
        return new ExchangePatternProcessor(parse(ExchangePattern.class, definition.getPattern()));
    }
}

==> apache-camel-4.15.0-src.zip: apache-camel-4.15.0/core/camel-core-reifier/src/main/java/org/apache/camel/reifier/SetExchangePatternReifier.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.reifier;

import org.apache.camel.ExchangePattern;
import org.apache.camel.Processor;
import org.apache.camel.Route;
import org.apache.camel.model.ProcessorDefinition;
import org.apache.camel.model.SetExchangePatternDefinition;
import org.apache.camel.processor.ExchangePatternProcessor;

public class SetExchangePatternReifier extends ProcessorReifier<SetExchangePatternDefinition> {

    public SetExchangePatternReifier(Route route, ProcessorDefinition<?> definition) {
        super(route, (SetExchangePatternDefinition) definition);
    }

    @Override
    public Processor createProcessor() {
        ExchangePatternProcessor answer = new ExchangePatternProcessor(parse(ExchangePattern.class, definition.getPattern()));
        answer.setDisabled(isDisabled(camelContext, definition));
        return answer;
    }
}
